def to_bool(v):
    if v in ["True", "true", True]:
        return True
    elif v in ["False", "false", False]:
        return False
    else:
        return None


def toType(val, typ):
    val_type = type(val)
    if typ in [str, float]:
        return typ(val) if val_type != list else [typ(item) for item in val]
    elif typ == int:
        try:
            return typ(val) if val_type != list else [typ(item) for item in val]
        except:
            return float(val) if val_type != list else [float(item) for item in val]
    elif typ == bool:
        return to_bool(val) if val_type != list else [to_bool(item) for item in val]


def useDefaultType(val, default):
    val_type = type(val)
    default_type = type(default)

    # 根据 default 的类型进行转换
    if default_type in [str, int, float, bool]:
        try:
            val = toType(val, default_type)
            if val_type == list:
                try:
                    val = val[0]
                except:
                    return default
        except:
            return None
    elif default_type == list:
        try:
            if len(default) > 0:
                if val_type != list:
                    val = [useDefaultType(val, default[0])]
                # 判断 default 列表中元素的类型，假设所有元素类型相同
                if len(val) > 0:
                    element_type = type(default[0])
                    if type(val[0]) is element_type:
                        val = toType(val, element_type)
                else:
                    val = []
            else:
                if val_type != list:
                    val = [val]
        except:
            return None
    return val




import json
from pycoze import utils
import json
import inspect


params_file = utils.read_arg("params_file", True)
params = None
try:
    with open(params_file, "r", encoding="utf-8") as f:
        params = json.load(f)
except Exception as e:
    print(e)


def get_ui():
    if params is None:
        return {}
    stack = inspect.stack()
    stack_files = list(reversed([s.filename.replace("\\", "/") for s in stack]))
    match_item = None
    for f in stack_files:
        for v in params["uiData"]["uiFiles"]:
            if v == f:
                match_item = v
                break
        if match_item:
            break

    if not match_item:
        raise Exception("uiData not found for file")

    by = match_item["by"]

    for i in range(10):
        try:
            if by == "file":
                json_file = match_item["Jsonfile"]
                with open(json_file, "r", encoding="utf-8") as f:
                    return json.load(f)
            else:
                assert by == "node"
                workflow_file = match_item["workflowFile"]
                node_id = match_item["nodeId"]
                with open(workflow_file, "r", encoding="utf-8") as f:
                    cells = json.load(f)["graph"]["cells"]
                    node = [cell for cell in cells if cell["id"] == node_id][0]
                    return json.loads(node["data"]["ui"])
        except Exception as e:
            if i == 9:
                raise e
